netapp_ontap.models.gcp_kms_state API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.gcp_kms_state`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class GcpKmsStateSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the GcpKmsState object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cluster_state GET`

    Set to true when Google Cloud KMS key protection is available on all nodes of the cluster.

  `code GET`

    Error code corresponding to the status message. Returns 0 if Google Cloud KMS key protection is available in all nodes of the cluster.

    Example: 346758

  `message GET`

    Error message set when cluster availability is false. This field will be empty when cluster availability is true. Cluster availability refers to the cluster-wide state of the embedded KMIP server's client on all nodes.

    Example: Google Cloud KMS key protection is unavailable in following nodes - node1, node2.